<?php

namespace Drupal\entity_wishlist\Controller;

/**
 * @file
 * Contains \Drupal\entity_wishlist\Controller\EntityUserWishlistController.
 */


use Drupal\Core\Controller\ControllerBase;
use Drupal\user\UserInterface;
use Drupal\node\Entity\Node;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\user\Entity\User;

/**
 * A EntityUserWishlistController controller.
 */
class EntityUserWishlistController extends ControllerBase {

  /**
   * {@inheritdoc}
   */
  public function content(UserInterface $user) {
    $user = User::load(\Drupal::currentUser()->id());
    $uid = $user->get('uid')->value;
    $header = [
      ['data' => t('No.')],
      ['data' => t('Title')],
    ];
    $db = \Drupal::database();
    $query = $db->select('entity_wishlist', 'ew');
    $query->fields('ew', ["wid", "entity_id")];
    $query->condition('uid', $uid, "=");
    $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(10);
    $list_records = $pager->execute()->fetchAll();
    $rows = [];
    foreach ($list_records as $key => $data) {
      $node = Node::load($data->entity_id);
      $node_title = $node->getTitle();
      $path = "/node/" . $data->entity_id;
      $url = Url::fromUri('internal:' . $path);
      $link = Link::fromTextAndUrl($node_title, $url);
      $rows[] = [
        'data' => [
          'name' => $key + 1,
          'content' => $link,
        ],
      ];
    }
    $build['config_table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      "#empty" => t("No record found."),
    ];
    $build['pager'] = [
      '#type' => 'pager',
    ];
    return $build;
  }

}
