<?php

namespace Drupal\entity_wishlist\Form;

/**
 * @file
 * Contains Drupal\entity_wishlist\Form\EntityWishlistConfigurationForm.
 */


use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 */
class EntityWishlistConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'entitywishlist.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_wishlist_configuration_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('entitywishlist.settings');
    $contentTypes = \Drupal::service('entity.manager')->getStorage('node_type')->loadMultiple();

    $contentTypesList = [];
    foreach ($contentTypes as $contentType) {
      $contentTypesList[$contentType->id()] = $contentType->label();
    }
    $form['entitywishlist_content_type'] = [
      '#type' => 'checkboxes',
      '#cache' => ['max-age' => 0],
      '#options' => $contentTypesList,
      '#default_value' => $config->get('entitywishlist_content_type'),
      '#title' => t('Please choose any content type which you want for wishlist.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('entitywishlist.settings')
      ->set('entitywishlist_content_type', $form_state->getValue('entitywishlist_content_type'))
      ->save();
    drupal_flush_all_caches();
  }

}
